@@ -2,7 +2,7 @@
 //
 // Export a Rivendell Report to an ASCII Text File.
 //
-//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,8 @@
 #include <rdreport.h>
 
 
-bool RDReport::ExportMusicSummary(const QDate &startdate,const QDate &enddate,
+bool RDReport::ExportMusicSummary(const QString &filename,
+				  const QDate &startdate,const QDate &enddate,
 				  const QString &mixtable)
 {
   QString sql;
@@ -39,14 +40,6 @@ bool RDReport::ExportMusicSummary(const QDate &startdate,const QDate &enddate,
   QString cut;
   QString str;
 
-#ifdef WIN32
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
-#else
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
-#endif
-
   QFile file(filename);
   if((f=fopen((const char *)filename,"w"))==NULL) {
     report_error_code=RDReport::ErrorCantOpen;
