@@ -2,7 +2,7 @@
 //
 // Export a Rivendell Spin Count Report to an ASCII Text File.
 //
-//   (C) Copyright 2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2015,2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,9 +31,8 @@
 #include <rddatedecode.h>
 #include <rdreport.h>
 
-
-bool RDReport::ExportSpinCount(const QDate &startdate,const QDate &enddate,
-			       const QString &mixtable)
+bool RDReport::ExportSpinCount(const QString &filename,const QDate &startdate,
+			       const QDate &enddate,const QString &mixtable)
 {
   QString sql;
   RDSqlQuery *q;
@@ -48,15 +47,6 @@ bool RDReport::ExportSpinCount(const QDate &startdate,const QDate &enddate,
   std::map<unsigned,QString> labels;
   std::map<unsigned,QString> albums;
 
-
-#ifdef WIN32
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
-#else
-  QString filename=
-    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
-#endif
-
   QFile file(filename);
   if((f=fopen((const char *)filename,"w"))==NULL) {
     report_error_code=RDReport::ErrorCantOpen;
