@@ -511,6 +511,30 @@
         <source>template host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished">Conteúdo</translation>
+    </message>
+    <message>
+        <source>Log already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>No such service!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No such group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No free cart available in group</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -879,10 +903,6 @@ Cor</translation>
         <source>Unable to create temporary cart for import!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to get temporary cart number for import!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import Error</source>
         <translation type="unfinished"></translation>
@@ -1876,11 +1896,11 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
     <name>RDListLogs</name>
     <message>
         <source>Select Log - User: </source>
-        <translation>Selecionar Lista - Usuario: </translation>
+        <translation type="obsolete">Selecionar Lista - Usuario: </translation>
     </message>
     <message>
         <source>Select Log</source>
-        <translation>Selecione Lista</translation>
+        <translation type="unfinished">Selecione Lista</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -1902,6 +1922,10 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="obsolete">TODOS</translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -1923,6 +1947,29 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
         <translation>Serviços Ativos</translation>
     </message>
 </context>
+<context>
+    <name>RDLogFilter</name>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Limpar</translation>
+    </message>
+    <message>
+        <source>Show Only Recent Logs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished">TODOS</translation>
+    </message>
+</context>
 <context>
     <name>RDLogLine</name>
     <message>
@@ -2341,5 +2388,13 @@ por favor, tente novamente!</translation>
         <translation>Erros de Auto Preenchimento
 </translation>
     </message>
+    <message>
+        <source>Log in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import failed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
