@@ -18,40 +18,20 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <rddb.h>
-#include <rdconf.h>
-#include <rdlog.h>
-#include <rdlog_line.h>
-#include <rdescape_string.h>
-#include <rdweb.h>
+#include <qobject.h>
 
-//
-// Global Classes
-//
-RDLog::RDLog(const QString &name,bool create)
+#include "rddb.h"
+#include "rdconf.h"
+#include "rdcreate_log.h"
+#include "rdescape_string.h"
+#include "rdlog.h"
+#include "rdlog_line.h"
+#include "rdsvc.h"
+#include "rdweb.h"
+
+RDLog::RDLog(const QString &name)
 {
-  RDSqlQuery *q;
-  QString sql;
-
   log_name=name;
-
-  if(create) {
-    sql=QString("select NAME from LOGS where ")+
-      "(NAME=\""+RDEscapeString(log_name)+"\")";
-    q=new RDSqlQuery(sql);
-    if(q->size()!=1) {
-      delete q;
-      sql=QString().
-        sprintf("INSERT INTO LOGS SET NAME=\"%s\",ORIGIN_DATETIME=NOW(),\
-                 LINK_DATETIME=NOW(),MODIFIED_DATETIME=now()",
-		(const char *)RDEscapeString(log_name));
-      q=new RDSqlQuery(sql);
-      delete q;
-    }
-    else {
-      delete q;
-    }
-  }
 }
 
 
@@ -370,13 +350,11 @@ bool RDLog::remove(RDStation *station,RDUser *user,RDConfig *config) const
 {
   QString sql;
   RDSqlQuery *q;
-  QString name=log_name;
 
-  name.replace(" ","_");
   if(removeTracks(station,user,config)<0) {
     return false;
   }
-  sql=QString().sprintf("drop table `%s_LOG`",(const char *)name);
+  sql=QString("drop table `")+RDLog::tableName(log_name)+"`";
   q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from LOGS where (NAME=\"%s\" && TYPE=0)",
@@ -394,8 +372,10 @@ void RDLog::updateTracks()
   unsigned scheduled=0;
   unsigned completed=0;
 
-  sql=QString().sprintf("select NUMBER from CART where OWNER=\"%s\"",
-			(const char *)RDEscapeString(log_name));
+  sql=QString("select `")+RDLog::tableName(log_name)+"`.ID from "+
+    "`"+RDLog::tableName(log_name)+"` left join CART "+
+    "on `"+RDLog::tableName(log_name)+"`.CART_NUMBER=CART.NUMBER where "+
+    "CART.OWNER is not null";
   q=new RDSqlQuery(sql);
   completed=q->size();
   delete q;
@@ -506,6 +486,70 @@ QString RDLog::xml() const
 }
 
 
+bool RDLog::create(const QString &name,const QString &svc_name,
+		   const QDate &air_date,const QString &user_name,
+		   QString *err_msg,RDConfig *config)
+{
+  QString sql;
+  RDSqlQuery *q;
+  int shelflife=-1;
+  RDSvc::ShelflifeOrigin shelforigin;
+  QString desc_tmpl;
+
+  sql=QString("select ")+
+    "DEFAULT_LOG_SHELFLIFE,"+  // 00
+    "LOG_SHELFLIFE_ORIGIN,"+   // 01
+    "DESCRIPTION_TEMPLATE "+   // 02
+    "from SERVICES where "+
+    "NAME=\""+RDEscapeString(svc_name)+"\"";
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    shelflife=q->value(0).toInt();
+    shelforigin=(RDSvc::ShelflifeOrigin)q->value(1).toInt();
+    desc_tmpl=q->value(2).toString();
+  }
+  else {
+    *err_msg=QObject::tr("No such service!");
+    delete q;
+    return false;
+  }
+  delete q;
+  sql=QString("insert into LOGS set ")+
+    "NAME=\""+RDEscapeString(name)+"\","+
+    "TYPE=0,"+
+    "DESCRIPTION=\""+RDEscapeString(name)+" log \","+
+    "ORIGIN_USER=\""+RDEscapeString(user_name)+"\","+
+    "ORIGIN_DATETIME=now(),"+
+    "LINK_DATETIME=now(),"+
+    "SERVICE=\""+RDEscapeString(svc_name)+"\"";
+  if(shelflife>=0) {
+    switch(shelforigin) {
+    case RDSvc::OriginCreationDate:
+      sql+=",PURGE_DATE=\""+
+	QDate::currentDate().addDays(shelflife).toString("yyyy-MM-dd")+"\"";
+      break;
+
+    case RDSvc::OriginAirDate:
+      if(air_date.isValid()) {
+	sql+=",PURGE_DATE=\""+
+	  air_date.addDays(shelflife).toString("yyyy-MM-dd")+"\"";
+      }
+      break;
+    }
+  }
+  q=new RDSqlQuery(sql);
+  if(!q->isActive()) {
+    *err_msg=QObject::tr("Log already exists!");
+    delete q;
+    return false;
+  }
+  delete q;
+  RDCreateLogTable(RDLog::tableName(name),config);
+  *err_msg=QObject::tr("OK");
+  return true;
+}
+
+
 bool RDLog::exists(const QString &name)
 {
   QString sql;
@@ -522,6 +566,18 @@ bool RDLog::exists(const QString &name)
 }
 
 
+bool RDLog::remove(const QString &name,RDStation *station,RDUser *user,
+		   RDConfig *config)
+{
+  RDLog *log=new RDLog(name);
+  bool ret=false;
+
+  ret=log->remove(station,user,config);
+  delete log;
+  return ret;
+}
+
+
 QString RDLog::tableName(const QString &log_name)
 {
   QString ret=log_name;
