@@ -38,7 +38,8 @@ class RDMatrix
 	     BtSrc16=24,Harlond=25,Acu1p=26,LiveWireMcastGpio=27,Am16=28,
 	     LiveWireLwrpGpio=29,BtSentinel4Web=30,BtGpi16=31,ModemLines=32,
 	     SoftwareAuthority=33,Sas16000=34,RossNkScp=35,BtAdms4422=36,
-	     BtSs41Mlr=37,Modbus=38,KernelGpio=39,LastType=40};
+	     BtSs41Mlr=37,Modbus=38,KernelGpio=39,WheatnetSlio=40,
+	     WheatnetLio=41,BtU41MlrWeb=42,LastType=43};
   enum Endpoint {Input=0,Output=1};
   enum Mode {Stereo=0,Left=1,Right=2};
   enum VguestAttribute {VguestEngine=0,VguestDevice=1,VguestSurface=2,
