@@ -2,9 +2,7 @@
 //
 //   An audio- and touchscreen-friendly slider widget.
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdslider.cpp,v 1.1 2007/09/14 14:06:24 fredg Exp $
+//   (C) Copyright 2009,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -30,32 +28,31 @@
 #include <qpalette.h>
 #include <qsize.h>
 #include <qrect.h>
+#include <rdslider.h>
 #include <qpixmap.h>
 
-#include <rdslider.h>
 
-
-RDSlider::RDSlider(QWidget *parent=0,const char *name=0)
-  : QWidget(parent,name),QRangeControl()
+RDSlider::RDSlider(QWidget *parent=0)
+  : QWidget(parent),QRangeControl()
 {
-  init();
+  init(RDSlider::Right);
   update();
 }
 
 
-RDSlider::RDSlider(RDSlider::Orientation orient,QWidget *parent,const char *name)
-  : QWidget(parent,name),QRangeControl()
+RDSlider::RDSlider(RDSlider::Orientation orient,QWidget *parent)
+  : QWidget(parent),QRangeControl()
 {
-  init();
+  init(orient);
   setOrientation(orient);
 }
 
 
 RDSlider::RDSlider(int minValue,int maxValue,int pageStep,int value,
-	   RDSlider::Orientation orient,QWidget *parent,const char *name)
-  : QWidget(parent,name),QRangeControl()
+	   RDSlider::Orientation orient,QWidget *parent)
+  : QWidget(parent),QRangeControl()
 {
-  init();
+  init(orient);
   setOrientation(orient);
   setRange(minValue,maxValue);
   setPageStep(pageStep);
@@ -65,13 +62,13 @@ RDSlider::RDSlider(int minValue,int maxValue,int pageStep,int value,
 
 RDSlider::Orientation RDSlider::orientation() const
 {
-  return slider_orient;
+  return rdslider_orient;
 }
 
 
 void RDSlider::setOrientation(RDSlider::Orientation orient)
 {
-  slider_orient=orient;
+  rdslider_orient=orient;
   update();
 }
 
@@ -181,10 +178,9 @@ void RDSlider::setGeometry(QRect &rect)
 
 void RDSlider::setValue(int setting)
 {
-  if(!slider_moving) { 
+  if(!rdslider_moving) { 
    if(setting!=value()) {
       QRangeControl::setValue(setting);
-      emit valueChanged(value());
       calcKnob();
       update(prev_knob);
       update(curr_knob);
@@ -210,7 +206,7 @@ void RDSlider::paintEvent(QPaintEvent *paintEvent)
   QPainter *p=new QPainter(this);
   int tick_x,tick_y;
 
-  if((slider_orient==RDSlider::Up)||(slider_orient==RDSlider::Down)) {
+  if((rdslider_orient==RDSlider::Up)||(rdslider_orient==RDSlider::Down)) {
     //
     // The groove
     //
@@ -225,7 +221,7 @@ void RDSlider::paintEvent(QPaintEvent *paintEvent)
     //
     // The ticks
     //
-    switch(slider_orient) {
+    switch(rdslider_orient) {
 	case RDSlider::Up:
 	  if((tick_setting==QSlider::Left)||(tick_setting==QSlider::Both)) {
 	    p->setPen(colorGroup().shadow());
@@ -275,7 +271,7 @@ void RDSlider::paintEvent(QPaintEvent *paintEvent)
 	  break;
     }
   }
-  if((slider_orient==RDSlider::Left)||(slider_orient==RDSlider::Right)) {
+  if((rdslider_orient==RDSlider::Left)||(rdslider_orient==RDSlider::Right)) {
     //
     // The groove
     //
@@ -292,7 +288,7 @@ void RDSlider::paintEvent(QPaintEvent *paintEvent)
     //
     // The ticks
     //
-    switch(slider_orient) {
+    switch(rdslider_orient) {
 	case RDSlider::Left:
 	  if((tick_setting==QSlider::Above)||(tick_setting==QSlider::Both)) {
 	    p->setPen(colorGroup().shadow());
@@ -357,13 +353,13 @@ void RDSlider::mouseMoveEvent(QMouseEvent *mouse)
   int curr_x,curr_y;
   int knob_value;
 
-  if(slider_moving) {
+  if(rdslider_moving) {
     prev_knob=curr_knob;
-    if((slider_orient==RDSlider::Up)||(slider_orient==RDSlider::Down)) {
+    if((rdslider_orient==RDSlider::Up)||(rdslider_orient==RDSlider::Down)) {
       if(mouse->y()<0) {
 	curr_knob=QRect(curr_knob.x(),0,curr_knob.width(),curr_knob.height());
 	if(prev_knob!=curr_knob) {
-	  switch(slider_orient) {
+	  switch(rdslider_orient) {
 	      case RDSlider::Up:
 		if(value()!=maxValue()) {
 		  QRangeControl::setValue(maxValue());
@@ -400,7 +396,7 @@ void RDSlider::mouseMoveEvent(QMouseEvent *mouse)
 	curr_knob=QRect(curr_knob.x(),height()-curr_knob.height(),
 			curr_knob.width(),curr_knob.height());
 	if(prev_knob!=curr_knob) {
-	  switch(slider_orient) {
+	  switch(rdslider_orient) {
 	      case RDSlider::Up:
 		if(value()!=minValue()) {
 		  QRangeControl::setValue(minValue());
@@ -443,7 +439,7 @@ void RDSlider::mouseMoveEvent(QMouseEvent *mouse)
       curr_knob=QRect(curr_knob.x(),curr_y,
 		      curr_knob.width(),curr_knob.height());
       base_y=mouse->y();
-      switch(slider_orient) {
+      switch(rdslider_orient) {
 	  case RDSlider::Up:
 	    knob_value=(maxValue()-minValue())*
 				    (geometry().height()-curr_knob.y()
@@ -485,11 +481,11 @@ void RDSlider::mouseMoveEvent(QMouseEvent *mouse)
       update(curr_knob);
     }
 
-    if((slider_orient==RDSlider::Left)||(slider_orient==RDSlider::Right)) {
+    if((rdslider_orient==RDSlider::Left)||(rdslider_orient==RDSlider::Right)) {
       if(mouse->x()<0) {
 	curr_knob=QRect(0,curr_knob.y(),curr_knob.width(),curr_knob.height());
 	if(prev_knob!=curr_knob) {
-	  switch(slider_orient) {
+	  switch(rdslider_orient) {
 	      case RDSlider::Left:
 		if(value()!=maxValue()) {
 		  QRangeControl::setValue(maxValue());
@@ -526,7 +522,7 @@ void RDSlider::mouseMoveEvent(QMouseEvent *mouse)
 	curr_knob=QRect(width()-curr_knob.width(),curr_knob.y(),
 			curr_knob.width(),curr_knob.height());
 	if(prev_knob!=curr_knob) {
-	  switch(slider_orient) {
+	  switch(rdslider_orient) {
 	      case RDSlider::Left:
 		if(value()!=minValue()) {
 		  QRangeControl::setValue(minValue());
@@ -569,7 +565,7 @@ void RDSlider::mouseMoveEvent(QMouseEvent *mouse)
       curr_knob=QRect(curr_x,curr_knob.y(),
 		      curr_knob.width(),curr_knob.height());
       base_x=mouse->x();
-      switch(slider_orient) {
+      switch(rdslider_orient) {
 	  case RDSlider::Left:
 	    knob_value=(maxValue()-minValue())*
 				    (geometry().width()-curr_knob.x()
@@ -619,7 +615,7 @@ void RDSlider::mousePressEvent(QMouseEvent *mouse)
     if(curr_knob.contains(mouse->x(),mouse->y())) {
       base_x=mouse->x();
       base_y=mouse->y();
-      slider_moving=true;
+      rdslider_moving=true;
       emit sliderPressed();
       return;
     }
@@ -640,7 +636,7 @@ void RDSlider::mousePressEvent(QMouseEvent *mouse)
 void RDSlider::mouseReleaseEvent(QMouseEvent *mouse)
 {
   if(mouse->button()==QMouseEvent::LeftButton) {
-    slider_moving=false;
+    rdslider_moving=false;
     if(deferred_change) {
       emit valueChanged(value());
       deferred_change=false;
@@ -650,11 +646,12 @@ void RDSlider::mouseReleaseEvent(QMouseEvent *mouse)
 }
 
 
-void RDSlider::init()
+void RDSlider::init(RDSlider::Orientation orient)
 {
+  rdslider_orient=orient;
   knob_map=NULL;
   knob_color=colorGroup();
-  slider_moving=false;
+  rdslider_moving=false;
   page_step=10;
   line_step=1;
   tracking_enabled=true;
@@ -681,14 +678,14 @@ void RDSlider::calcKnob(int x,int y,int w,int h)
   int knob_h=0;
   QPainter p;
 
-  if((slider_orient==RDSlider::Up)||(slider_orient==RDSlider::Down)) {
+  if((rdslider_orient==RDSlider::Up)||(rdslider_orient==RDSlider::Down)) {
     //
     // The knob itself
     //
     knob_w=knob_size.width();
     knob_h=knob_size.height();
     knob_x=w/2-knob_w/2;
-    switch(slider_orient) {
+    switch(rdslider_orient) {
 	case RDSlider::Up:
 	  knob_y=(h-knob_h)-((h-knob_h)*(value()-minValue()))/
 	    (maxValue()-minValue());
@@ -715,11 +712,11 @@ void RDSlider::calcKnob(int x,int y,int w,int h)
     //
     // The PageUp/PageDown areas
     //
-    if(slider_orient==RDSlider::Up) {
+    if(rdslider_orient==RDSlider::Up) {
       page_up=QRect(knob_x,0,knob_w,knob_y);
       page_down=QRect(knob_x,knob_y+knob_h,knob_w,height()-(knob_y+knob_h));
     }
-    if(slider_orient==RDSlider::Down) {
+    if(rdslider_orient==RDSlider::Down) {
       page_down=QRect(knob_x,0,knob_w,knob_y);
       page_up=QRect(knob_x,knob_y+knob_h,knob_w,height()-(knob_y+knob_h));
     }
@@ -767,14 +764,14 @@ void RDSlider::calcKnob(int x,int y,int w,int h)
     }
     p.end();
   }
-  if((slider_orient==RDSlider::Left)||(slider_orient==RDSlider::Right)) {
+  if((rdslider_orient==RDSlider::Left)||(rdslider_orient==RDSlider::Right)) {
     //
     // The knob itself
     //
     knob_w=knob_size.width();
     knob_h=knob_size.height();
     knob_y=h/2-knob_h/2;
-    switch(slider_orient) {
+    switch(rdslider_orient) {
 	case RDSlider::Left:
 	  knob_x=(w-knob_w)-((w-knob_w)*(value()-minValue()))/
 	    (maxValue()-minValue());
@@ -794,18 +791,15 @@ void RDSlider::calcKnob(int x,int y,int w,int h)
     else {
       curr_knob=QRect(knob_x,knob_y,1,1);
     }
-    if(prev_knob!=curr_knob) {
-      emit sliderMoved(value());
-    }
     
     //
     // The PageUp/PageDown areas
     //
-    if(slider_orient==RDSlider::Right) {
+    if(rdslider_orient==RDSlider::Right) {
       page_up=QRect(knob_x+knob_w,knob_y,x+w,knob_h);
       page_down=QRect(0,knob_y,knob_x,knob_y+knob_h);
     }
-    if(slider_orient==RDSlider::Left) {
+    if(rdslider_orient==RDSlider::Left) {
       page_down=QRect(knob_x+knob_w,knob_y,x+w,knob_h);
       page_up=QRect(0,knob_y,knob_x,knob_y+knob_h);
     }
