@@ -2,9 +2,7 @@
 //
 // Get the trim points for an audio cut.
 //
-//   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdtrimaudio.cpp,v 1.6.4.1 2012/12/13 22:33:45 cvs Exp $
+//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -47,11 +45,11 @@ size_t RDTrimAudioCallback(void *ptr,size_t size,size_t nmemb,void *userdata)
 }
 
 
-RDTrimAudio::RDTrimAudio(RDStation *station,
-			     QObject *parent,const char *name)
-  : QObject(parent,name)
+RDTrimAudio::RDTrimAudio(RDStation *station,RDConfig *config,QObject *parent)
+  : QObject(parent)
 {
   conv_station=station;
+  conv_config=config;
   conv_cart_number=0;
   conv_cut_number=0;
   conv_start_point=-1;
@@ -116,12 +114,14 @@ RDTrimAudio::ErrorCode RDTrimAudio::runTrim(const QString &username,
   // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
   // error.
   //
-  strncpy(url,conv_station->webServiceUrl(),1024);
+  strncpy(url,conv_station->webServiceUrl(conv_config),1024);
   curl_easy_setopt(curl,CURLOPT_URL,url);
   curl_easy_setopt(curl,CURLOPT_WRITEFUNCTION,RDTrimAudioCallback);
   curl_easy_setopt(curl,CURLOPT_WRITEDATA,&conv_xml);
   curl_easy_setopt(curl,CURLOPT_POST,1);
   curl_easy_setopt(curl,CURLOPT_POSTFIELDS,(const char *)post);
+  curl_easy_setopt(curl,CURLOPT_USERAGENT,
+		   (const char *)conv_config->userAgent());
   curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
 
   switch(curl_err=curl_easy_perform(curl)) {
@@ -137,6 +137,7 @@ RDTrimAudio::ErrorCode RDTrimAudio::runTrim(const QString &username,
   case CURLE_OUT_OF_MEMORY:
   case CURLE_OPERATION_TIMEDOUT:
   case CURLE_HTTP_POST_ERROR:
+  default:
     //fprintf(stderr,"CURL Error: %s [%d]\n",curl_easy_strerror(curl_err),
     //curl_err);
     curl_easy_cleanup(curl);
@@ -154,8 +155,12 @@ RDTrimAudio::ErrorCode RDTrimAudio::runTrim(const QString &username,
 
   switch(response_code) {
   case 200:
+    //printf("XML: %s\n",(const char *)conv_xml);
     break;
 
+  case 404:
+    return RDTrimAudio::ErrorNoAudio;
+
   default:
     return RDTrimAudio::ErrorService;
   }
@@ -168,7 +173,7 @@ RDTrimAudio::ErrorCode RDTrimAudio::runTrim(const QString &username,
 
 QString RDTrimAudio::errorText(RDTrimAudio::ErrorCode err)
 {
-  QString ret=QString().sprintf("Uknown Error [%u]",err);
+  QString ret=QString().sprintf("Unknown Error [%u]",err);
 
   switch(err) {
   case RDTrimAudio::ErrorOk:
@@ -190,6 +195,10 @@ QString RDTrimAudio::errorText(RDTrimAudio::ErrorCode err)
   case RDTrimAudio::ErrorInvalidUser:
     ret=tr("Invalid user or password");
     break;
+
+  case RDTrimAudio::ErrorNoAudio:
+    ret=tr("No audio data");
+    break;
   }
   return ret;
 }
