@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell TTY
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdtty.h,v 1.4 2007/02/14 21:48:41 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,7 +19,8 @@
 //
 
 #include <qsqldatabase.h>
-#include <rttydevice.h>
+
+#include <rdttydevice.h>
 
 #ifndef RDTTY_H
 #define RDTTY_H
@@ -30,7 +29,7 @@ class RDTty
 {
   public:
    enum Termination {NoTerm=0,CrTerm=1,LfTerm=2,CrLfTerm=3};
-   RDTty(QString station,unsigned port_id,bool create=false);
+   RDTty(const QString &station,unsigned port_id,bool create=false);
    QString station() const;
    int portId() const;
    bool active();
@@ -43,18 +42,18 @@ class RDTty
    void setDataBits(int bits);
    int stopBits();
    void setStopBits(int bits);
-   RTTYDevice::Parity parity();
-   void setParity(RTTYDevice::Parity);
+   RDTTYDevice::Parity parity();
+   void setParity(RDTTYDevice::Parity);
    RDTty::Termination termination();
    void setTermination(RDTty::Termination term);
 
   private:
-   bool GetBoolValue(QString field);
-   QString GetStringValue(QString field);
-   int GetIntValue(QString field);
-   void SetRow(QString param,bool value);
-   void SetRow(QString param,QString value);
-   void SetRow(QString param,int value);
+   bool GetBoolValue(const QString &field);
+   QString GetStringValue(const QString &field);
+   int GetIntValue(const QString &field);
+   void SetRow(const QString &param,bool value);
+   void SetRow(const QString &param,const QString &value);
+   void SetRow(const QString &param,int value);
    QString tty_station;
    int tty_id;
 };
