@@ -51,6 +51,10 @@
 #define RDXPORT_COMMAND_SAVELOG 28
 #define RDXPORT_COMMAND_ADDLOG 29
 #define RDXPORT_COMMAND_DELETELOG 30
+#define RDXPORT_COMMAND_CREATETICKET 31
+#define RDXPORT_COMMAND_REHASH 32
+#define RDXPORT_COMMAND_LISTSYSTEMSETTINGS 33
+#define RDXPORT_COMMAND_LOCKLOG 34
 
 
 #endif  // RDXPORT_INTERFACE_H
