@@ -2,9 +2,7 @@
 //
 // Add a Rivendell Report
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_report.h,v 1.3 2007-02-14 21:51:01 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,12 +28,11 @@
 
 #include <rdreport.h>
 
-
 class AddReport : public QDialog
 {
  Q_OBJECT
  public:
-  AddReport(QString *rptname,QWidget *parent=0,const char *name=0);
+  AddReport(QString *rptname,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
