@@ -2,9 +2,7 @@
 //
 // Add a Rivendell Service
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: add_svc.cpp,v 1.18 2007/10/04 20:53:29 dmills Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,14 +31,15 @@
 #include <qbuttongroup.h>
 
 #include <rddb.h>
-#include <edit_svc.h>
-#include <add_svc.h>
 #include <rdpasswd.h>
 #include <rdtextvalidator.h>
 
+#include "add_svc.h"
+#include "edit_svc.h"
+#include "globals.h"
 
-AddSvc::AddSvc(QString *svcname,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+AddSvc::AddSvc(QString *svcname,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   svc_name=svcname;
 
@@ -63,17 +62,17 @@ AddSvc::AddSvc(QString *svcname,QWidget *parent,const char *name)
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // Service Name
   //
-  svc_name_edit=new QLineEdit(this,"svc_name_edit");
+  svc_name_edit=new QLineEdit(this);
   svc_name_edit->setGeometry(155,11,sizeHint().width()-165,19);
   svc_name_edit->setMaxLength(10);
   svc_name_edit->setValidator(validator);
-  QLabel *svc_name_label=new QLabel(svc_name_edit,tr("&New Service Name:"),
-				    this,"svc_name_label");
+  QLabel *svc_name_label=
+    new QLabel(svc_name_edit,tr("&New Service Name:"),this);
   svc_name_label->setGeometry(10,11,140,19);
   svc_name_label->setFont(font);
   svc_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -81,11 +80,10 @@ AddSvc::AddSvc(QString *svcname,QWidget *parent,const char *name)
   //
   // Exemplar
   //
-  svc_exemplar_box=new QComboBox(this,"svc_exemplar_box");
+  svc_exemplar_box=new QComboBox(this);
   svc_exemplar_box->setGeometry(155,36,sizeHint().width()-165,19);
   QLabel *svc_exemplar_label=
-    new QLabel(svc_exemplar_box,tr("Base Service On:"),
-	       this,"svc_exemplar_label");
+    new QLabel(svc_exemplar_box,tr("Base Service On:"),this);
   svc_exemplar_label->setGeometry(10,36,140,19);
   svc_exemplar_label->setFont(font);
   svc_exemplar_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
@@ -93,7 +91,7 @@ AddSvc::AddSvc(QString *svcname,QWidget *parent,const char *name)
   //
   //  Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this,"ok_button");
+  QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
   ok_button->setFont(font);
@@ -103,7 +101,7 @@ AddSvc::AddSvc(QString *svcname,QWidget *parent,const char *name)
   //
   //  Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
+  QPushButton *cancel_button=new QPushButton(this);
   cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
   cancel_button->setFont(font);
@@ -143,13 +141,24 @@ QSizePolicy AddSvc::sizePolicy() const
 
 void AddSvc::okData()
 {
+  QString err_msg;
+  QString exemplar="";
+
   if(svc_name_edit->text().isEmpty()) {
     QMessageBox::warning(this,tr("Invalid Name"),
 			 tr("You must give the service a name!"));
     return;
   }
 
-  RDSvc *svc=new RDSvc(svc_name_edit->text(),this,"svc");
+  if(svc_exemplar_box->currentItem()>0) {
+    exemplar=svc_exemplar_box->currentText();
+  }
+  if(!RDSvc::create(svc_name_edit->text(),&err_msg,exemplar,admin_config)) {
+    QMessageBox::warning(this,"RDAdmin - "+tr("Error"),err_msg);
+    return;
+  }
+  /*
+  RDSvc *svc=new RDSvc(svc_name_edit->text(),admin_station,admin_config,this);
   if(svc->exists()) {
     QMessageBox::warning(this,tr("Service Exists"),
 			 tr("Service Already Exists!"));
@@ -157,15 +166,16 @@ void AddSvc::okData()
     return;
   }
   if(svc_exemplar_box->currentItem()==0) {  // Create Empty Service
-    svc->create("");
+    svc->create("",admin_config);
   }
   else {
-    svc->create(svc_exemplar_box->currentText());
+    svc->create(svc_exemplar_box->currentText(),admin_config);
   }
   delete svc;
+  */
   *svc_name=svc_name_edit->text();
 
-  EditSvc *edit_svc=new EditSvc(svc_name_edit->text(),this,"svc");
+  EditSvc *edit_svc=new EditSvc(svc_name_edit->text(),this);
   if(edit_svc->exec()<0) {
     delete edit_svc;
     done(-1);
