@@ -291,11 +291,11 @@ un Log</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Ce Log existe</translation>
+        <translation type="obsolete">Ce Log existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Ce Log existe déjà !</translation>
+        <translation type="obsolete">Ce Log existe déjà !</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
@@ -397,12 +397,16 @@ la Fin</translation>
         <source>ALBUM</source>
         <translation>ALBUM</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Sélectionner un Log</translation>
+        <translation type="obsolete">Sélectionner un Log</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -430,7 +434,7 @@ la Fin</translation>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>S&amp;auver Sous</translation>
+        <translation type="obsolete">S&amp;auver Sous</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -440,6 +444,34 @@ la Fin</translation>
         <source>Rename Log</source>
         <translation>Renommer le Log</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must refresh the log before it can be saved.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
