@@ -427,14 +427,6 @@ New</source>
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Duplicate Event</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>An event with these parameters already exists!</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>EditRecording</name>
@@ -1257,5 +1249,13 @@ New</source>
         <source>PCM24</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Event Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Types</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
