@@ -2,9 +2,7 @@
 //
 // Edit Cart Notes.
 //
-//   (C) Copyright 2009 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_notes.h,v 1.1.2.1 2009/11/19 17:56:45 cvs Exp $
+//   (C) Copyright 2009,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,7 +32,7 @@ class EditNotes : public QDialog
 {
  Q_OBJECT
  public:
-  EditNotes(RDCart *cart,QWidget *parent=0,const char *name=0);
+  EditNotes(RDCart *cart,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
