@@ -126,7 +126,7 @@ List</source>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Tem certeza que quer 
+        <translation type="obsolete">Tem certeza que quer 
 deletar</translation>
     </message>
     <message>
@@ -191,6 +191,11 @@ Você quer salvar?</translation>
         <source>&amp;Clone</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Are you sure you want to delete
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -852,6 +857,30 @@ Re-agregar removerá estes dados.  Re-agregar? </translation>
         <source>Traffic Exists</source>
         <translation>Tráfego Existente</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to generate log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear traffic links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear music links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link music log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link traffic log</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
