@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for MeasurementComputing GPIO cards.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: local_gpio.h,v 1.8 2007/11/12 18:43:29 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,35 +21,40 @@
 #ifndef LOCAL_GPIO_H
 #define LOCAL_GPIO_H
 
-#include <qobject.h>
-
 #include <rdgpio.h>
 #include <rd.h>
 #include <rdmatrix.h>
 #include <rdmacro.h>
+#include <rdoneshot.h>
 
+#include <switcher.h>
 
-class LocalGpio : public QObject
+class LocalGpio : public Switcher
 {
  Q_OBJECT
  public:
-  LocalGpio(RDMatrix *matrix,QObject *parent=0,const char *name=0);
+  LocalGpio(RDMatrix *matrix,QObject *parent=0);
   ~LocalGpio();
+  RDMatrix::Type type();
+  unsigned gpiQuantity();
+  unsigned gpoQuantity();
+  bool primaryTtyActive();
+  bool secondaryTtyActive();
   void processCommand(RDMacro *cmd);
 
  private slots:
-  void inputChangedData(int line,bool state);
-
- signals:
-  void rmlEcho(RDMacro *cmd);
-  void gpiChanged(int matrix,int line,bool state);
+  void gpiChangedData(int line,bool state);
+  void gpoChangedData(int line,bool state);
+  void gpiOneshotData(int value);
 
  private:
   RDGpio *gpio_gpio;
+  RDOneShot *gpio_gpi_oneshot;
   int gpio_matrix;
   int gpio_gpis;
   int gpio_gpos;
   bool gpio_open;
+  bool gpio_gpi_mask[GPIO_MAX_LINES];
 };
 
 
