@@ -24,6 +24,7 @@
 #include <qdir.h>
 #include <qsessionmanager.h>
 #include <qsignalmapper.h>
+#include <qstringlist.h>
 
 #include <unistd.h>
 #include <stdio.h>
@@ -102,6 +103,7 @@ MainObject::MainObject(QObject *parent)
   //
   ripcd_config=new RDConfig(RD_CONF_FILE);
   ripcd_config->load();
+  ripcd_config->setModuleName("ripcd");
 
   //
   // Make sure we're the only instance running
@@ -701,6 +703,22 @@ void MainObject::ReadRmlSocket(QSocketDevice *dev,RDMacro::Role role,
   while((n=dev->readBlock(buffer,RD_RML_MAX_LENGTH))>0) {
     buffer[n]=0;
     if(macro.parseString(buffer,n)) {
+      if(macro.command()==RDMacro::AG) {
+	if(ripc_onair_flag) {
+	  QStringList f0=f0.split(" ",buffer);
+	  f0.pop_front();
+	  QString rmlstr=f0.join(" ");
+	  if(!macro.parseString(rmlstr,rmlstr.length())) {
+	    break;
+	  }
+	}
+	else {
+	  LogLine(RDConfig::LogDebug,
+		  QString("rejected rml: \"")+buffer+
+		  "\": on-air flag not active");
+	  break;
+	}
+      }
       macro.setRole(role);
       macro.setAddress(dev->peerAddress());
       macro.setEchoRequested(echo);
