@@ -2,9 +2,7 @@
 //
 // Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: ripcd.h,v 1.47.2.3 2009/08/07 01:14:08 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,6 +23,8 @@
 
 #include <sys/types.h>
 
+#include <vector>
+
 #include <qobject.h>
 #include <qstring.h>
 #include <qserversocket.h>
@@ -38,34 +38,15 @@
 #include <rdstation.h>
 #include <rdmatrix.h>
 #include <rdmacro.h>
+#include <rdtty.h>
 
+#include <ripcd_connection.h>
 #include <globals.h>
-#include <local_gpio.h>
-#include <sas32000.h>
-#include <sas64000.h>
-#include <unity4000.h>
-#include <bt10x1.h>
-#include <sas64000gpi.h>
-#include <btss82.h>
-#include <bt16x1.h>
-#include <bt8x2.h>
-#include <btacs82.h>
-#include <sasusi.h>
-#include <bt16x2.h>
-#include <btss124.h>
-#include <local_audio.h>
-#include <vguest.h>
-#include <btss164.h>
-#include <starguide3.h>
-#include <btss42.h>
-#include <livewire.h>
-#include <quartz1.h>
-#include <btss44.h>
+#include <switcher.h>
 
 //
 // Global RIPCD Definitions
 //
-#define RIPCD_MAX_CONNECTIONS 32
 #define RIPCD_MAX_LENGTH 256
 #define RIPCD_RML_READ_INTERVAL 100
 #define RIPCD_TTY_READ_INTERVAL 100
@@ -75,7 +56,7 @@ class MainObject : public QObject
 {
   Q_OBJECT
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
   ~MainObject();
 
  public slots:
@@ -96,10 +77,12 @@ class MainObject : public QObject
   void socketData(int);
   void socketKill(int);
   void checkMaintData();
+  void exitTimerData();
   
  private:
   void SetUser(QString username);
   void ExecCart(int cartnum);
+  void LogGpioEvent(int matrix,int line,RDMatrix::GpioType type,bool state);
   void ParseCommand(int);
   void DispatchCommand(int);
   void KillSocket(int);
@@ -121,51 +104,24 @@ class MainObject : public QObject
   void RunLocalMaintRoutine();
   int GetMaintInterval() const;
   void ForwardConvert(RDMacro *rml) const;
+  bool LoadSwitchDriver(int matrix_num);
   QSqlDatabase *ripcd_db;
   QString ripcd_host;
   bool debug;
   QServerSocket *server;
-  RDSocket *socket[RIPCD_MAX_CONNECTIONS];
-  char args[RIPCD_MAX_CONNECTIONS][RD_RML_MAX_ARGS][RD_RML_MAX_LENGTH];
-  int istate[RIPCD_MAX_CONNECTIONS];
-  int argnum[RIPCD_MAX_CONNECTIONS];
-  int argptr[RIPCD_MAX_CONNECTIONS];
-  bool auth[RIPCD_MAX_CONNECTIONS];
+  std::vector<RipcdConnection *> ripcd_conns;
   QSocketDevice *ripcd_rml_send;
   QSocketDevice *ripcd_rml_echo;
   QSocketDevice *ripcd_rml_noecho;
   QSocketDevice *ripcd_rml_reply;
   QHostAddress ripcd_host_addr;
-  RDMatrix::Type ripcd_matrix_type[MAX_MATRICES];
-  LocalGpio *ripcd_gpio[MAX_MATRICES];
-  Sas32000 *ripcd_sas32000[MAX_MATRICES];
-  Sas64000 *ripcd_sas64000[MAX_MATRICES];
-  Unity4000 *ripcd_unity4000[MAX_MATRICES];
-  Bt10x1 *ripcd_bt10x1[MAX_MATRICES];
-  Sas64000Gpi *ripcd_sas64000gpi[MAX_MATRICES];
-  BtSs82 *ripcd_btss82[MAX_MATRICES];
-  Bt16x1 *ripcd_bt16x1[MAX_MATRICES];
-  Bt8x2 *ripcd_bt8x2[MAX_MATRICES];
-  BtAcs82 *ripcd_btacs82[MAX_MATRICES];
-  SasUsi *ripcd_sasusi[MAX_MATRICES];
-  Bt16x2 *ripcd_bt16x2[MAX_MATRICES];
-  BtSs124 *ripcd_btss124[MAX_MATRICES];
-  LocalAudio *ripcd_local_audio[MAX_MATRICES];
-  VGuest *ripcd_vguest[MAX_MATRICES];
-  BtSs164 *ripcd_btss164[MAX_MATRICES];
-  StarGuide3 *ripcd_starguide3[MAX_MATRICES];
-  BtSs42 *ripcd_btss42[MAX_MATRICES];
-  LiveWire *ripcd_livewire[MAX_MATRICES];
-  Quartz1 *ripcd_quartz1[MAX_MATRICES];
-  BtSs44 *ripcd_btss44[MAX_MATRICES];
+  Switcher *ripcd_switcher[MAX_MATRICES];
   bool ripcd_gpi_state[MAX_MATRICES][MAX_GPIO_PINS];
   bool ripcd_gpo_state[MAX_MATRICES][MAX_GPIO_PINS];
   int ripcd_gpi_macro[MAX_MATRICES][MAX_GPIO_PINS][2];
   int ripcd_gpo_macro[MAX_MATRICES][MAX_GPIO_PINS][2];
   bool ripcd_gpi_mask[MAX_MATRICES][MAX_GPIO_PINS];
   bool ripcd_gpo_mask[MAX_MATRICES][MAX_GPIO_PINS];
-  int ripcd_gpis[MAX_MATRICES];
-  int ripcd_gpos[MAX_MATRICES];
   bool ripcd_tty_inuse[MAX_TTYS];
   int ripcd_switcher_tty[MAX_MATRICES][2];
   RDTTYDevice *ripcd_tty_dev[MAX_TTYS];
