@@ -2,9 +2,7 @@
 //
 // Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: ripcd_socket.h,v 1.6 2010/07/29 19:32:38 cvs Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,23 +26,21 @@
 #include <qserversocket.h>
 #include <qhostaddress.h>
 
-
 class RipcdSocket : public QServerSocket
 {
   Q_OBJECT
-  public:
-   RipcdSocket(Q_UINT16 port,int backlog=0,QObject *parent=0,
-	       const char *name=0);
-   RipcdSocket(const QHostAddress &address,Q_UINT16 port,int backlog=0,
-	       QObject *parent=0,const char *name=0);
-   void newConnection(int socket);
+ public:
+  RipcdSocket(Q_UINT16 port,int backlog=0,QObject *parent=0);
+  RipcdSocket(const QHostAddress &address,Q_UINT16 port,int backlog=0,
+	      QObject *parent=0);
+  void newConnection(int socket);
 
-  signals:
-   void connection(int);
+ signals:
+  void connection(int);
 
-  private:
-   QServerSocket *socket;
+ private:
+  QServerSocket *socket;
 };
 
 
-#endif 
+#endif  // RIPCD_SOCKET_H
